@@ -49,7 +49,7 @@ class QueriusClient:
         config = get_secret_json(secret_project, secret_name, secret_version)
         if not config:
             return
-        config['api_irl'] = api_url
+        config['api_url'] = api_url
         config['timeout_seconds'] = timeout_seconds
         return cls.from_service_account_info(**config)
 
