@@ -1,4 +1,5 @@
 from google.cloud.bigquery import QueryJob, Client
+from loguru import logger
 
 from querius.client import QueriusClient
 
@@ -10,6 +11,10 @@ def patch_bq_client_with_querius_client(bq_client: Client, qs_client: QueriusCli
     orig_query_method = bq_client.query
 
     def query(query_str: str, *query_args, **query_kwargs) -> QueryJob:
+        if 'project' in query_kwargs:
+            logger.warning("'project' argument passed to query method, not routing.")
+            return orig_query_method(query_str, *query_args, **query_kwargs)
+
         project, request_id = qs_client.route(query_str)
         query_kwargs['project'] = project
         qj = orig_query_method(query_str, *query_args, **query_kwargs)
